/*
 * Fabric3
 * Copyright (c) 2009 Metaform Systems
 *
 * Fabric3 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version, with the
 * following exception:
 *
 * Linking this software statically or dynamically with other
 * modules is making a combined work based on this software.
 * Thus, the terms and conditions of the GNU General Public
 * License cover the whole combination.
 *
 * As a special exception, the copyright holders of this software
 * give you permission to link this software with independent
 * modules to produce an executable, regardless of the license
 * terms of these independent modules, and to copy and distribute
 * the resulting executable under terms of your choice, provided
 * that you also meet, for each linked independent module, the
 * terms and conditions of the license of that module. An
 * independent module is a module which is not derived from or
 * based on this software. If you modify this software, you may
 * extend this exception to your version of the software, but
 * you are not obligated to do so. If you do not wish to do so,
 * delete this exception statement from your version.
 *
 * Fabric3 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the
 * GNU General Public License along with Fabric3.
 * If not, see <http://www.gnu.org/licenses/>.
*/
package org.fabric3.admin.interpreter.parser;

import java.util.HashMap;
import java.util.Map;

import org.fabric3.admin.api.DomainController;
import org.fabric3.admin.interpreter.CommandParser;
import org.fabric3.admin.interpreter.Settings;

/**
 * @version $Rev: 7906 $ $Date: 2009-11-23 15:41:50 +0000 (Mon, 23 Nov 2009) $
 */
public class ParserFactory {

    private ParserFactory() {
    }

    /**
     * Initializes the command parsers
     */
    public static Map<String, CommandParser> createParsers(DomainController controller, Settings settings) {
        Map<String, CommandParser> parsers = new HashMap<String, CommandParser>();
        AuthCommandParser authenticateParser = new AuthCommandParser(controller);
        parsers.put("au", authenticateParser);
        parsers.put("authenticate", authenticateParser);
        InstallCommandParser installParser = new InstallCommandParser(controller);
        parsers.put("install", installParser);
        parsers.put("ins", installParser);
        StatCommandParser statusParser = new StatCommandParser(controller);
        parsers.put("status", statusParser);
        parsers.put("st", statusParser);
        DeployCommandParser deployParser = new DeployCommandParser(controller);
        parsers.put("deploy", deployParser);
        parsers.put("de", deployParser);
        UndeployCommandParser undeployParser = new UndeployCommandParser(controller);
        parsers.put("undeploy", undeployParser);
        parsers.put("ude", undeployParser);
        RemoveCommandParser removeParser = new RemoveCommandParser(controller);
        parsers.put("uninstall", removeParser);
        parsers.put("uin", removeParser);
        parsers.put("use", new UseCommandParser(controller, settings));
        ProvisionCommandParser provisionParser = new ProvisionCommandParser(controller);
        parsers.put("pr", provisionParser);
        parsers.put("provision", provisionParser);
        ListCommandParser listCommandParser = new ListCommandParser(controller);
        parsers.put("ls", listCommandParser);
        parsers.put("list", listCommandParser);
        ProfileCommandParser profileCommandParser = new ProfileCommandParser(controller);
        parsers.put("profile", profileCommandParser);
        parsers.put("pf", profileCommandParser);
        return parsers;
    }

}
